@@ -68,21 +68,21 @@ def _api(api, op, group=_conf.DML_GROUP_ID, **kwargs):
         path = url.path
         assert all(x is not None for x in [scheme, host, port, path]), \
             f'invalid endpoint URL: {_conf.DML_API_ENDPOINT}'
-        Conn = (HTTPConnection if scheme == 'http' else HTTPSConnection)
+        conn = (HTTPConnection if scheme == 'http' else HTTPSConnection)(host, port)
         headers = {'content-type': 'application/json', 'accept': 'application/json'}
         if _conf.DML_API_KEY is not None:
             headers['x-daggerml-apikey'] = _conf.DML_API_KEY
         if group is not None:
             headers['x-daggerml-group'] = group
         while True:
-            conn = Conn(host, port)
             conn.request('POST', path, json.dumps(dict(api=api, op=op, **kwargs)), headers)
             resp = conn.getresponse()
+            data = resp.read()
             if resp.status != 504:
                 break
         if resp.status != 200:
             raise ApiError(f'{resp.status} {resp.reason}')
-        resp = json.loads(resp.read())
+        resp = json.loads(data)
         if resp['status'] != 'ok':
             err = resp['error']
             if err['context']:
